@@ -67,7 +67,7 @@ SludgeTranslationEditor::SludgeTranslationEditor()
 	theOriginalTextBuffer = GTK_TEXT_BUFFER (gtk_builder_get_object(theXml, "original_textbuffer"));
 	theTranslationTextBuffer = GTK_TEXT_BUFFER (gtk_builder_get_object(theXml, "translation_textbuffer"));
 
-    init(TRUE);
+	init(TRUE);
 }
 
 // Concrete methods for SludgeApplication:
@@ -77,6 +77,8 @@ gboolean SludgeTranslationEditor::init(gboolean calledFromConstructor)
 	currentFilename[0] = 0;
 	sprintf(currentShortname, "%s", getUntitledFilename());
 
+	badLangName = FALSE;
+
     return FALSE;
 }
 
@@ -102,31 +104,20 @@ const char * SludgeTranslationEditor::getUntitledFilename()
 
 gboolean SludgeTranslationEditor::saveFile(char *filename)
 {
-	gboolean retval;
-	char *latin1LangName;
-
-	latin1LangName = g_convert(gtk_entry_get_text(theLanguageEntry), -1, "ISO-8859-1", "UTF-8", NULL, NULL, NULL);
-	if (!latin1LangName) {
-		retval = FALSE;
-		errorBox("Invalid language name!", "The text in the 'Language name' field contains characters that have no representation in the ISO-8859-1 character encoding. Use this encoding for SLUDGE scripts and translation files. If you need support for translation files with other ISO-8859 encodings in the SLUDGE Translation Editor, contact the SLUDGE developers.");
-	} else {
-		retval = saveTranslationFile (filename, firstTransLine, latin1LangName, (unsigned int)gtk_adjustment_get_value(theIdAdjustment));
-		g_free(latin1LangName);
-	}
-	return retval;
+	return saveTranslationFile (filename, firstTransLine, gtk_entry_get_text(theLanguageEntry), (unsigned int)gtk_adjustment_get_value(theIdAdjustment));
 }
 
 gboolean SludgeTranslationEditor::loadFile(char *filename)
 {
 	unsigned int langID;
-	char *utf8LangName;
 	if (loadTranslationFile(filename, &firstTransLine, &langName, &langID)) {
 		gtk_adjustment_set_value(theIdAdjustment, (double)langID);
 		if (langName) {
-			utf8LangName = g_convert(langName, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
-			if (utf8LangName) {
-				gtk_entry_set_text(theLanguageEntry, utf8LangName);
-				g_free(utf8LangName);
+			if (g_utf8_validate(langName, -1, NULL)) {
+				badLangName = FALSE;
+				gtk_entry_set_text(theLanguageEntry, langName);
+			} else {
+				badLangName = TRUE;
 			}
 			deleteString(langName);
 			langName = NULL;
@@ -149,7 +140,6 @@ void SludgeTranslationEditor::postNew()
 	gtk_adjustment_set_value(theIdAdjustment, 0.);
 	gtk_entry_set_text(theLanguageEntry, "");
 	listChanged();
-	on_load_strings_clicked();
 }
 
 
@@ -169,23 +159,12 @@ void SludgeTranslationEditor::listChanged()
 		for (int k = 0; k < 2; k++) {
 			stringPtr = k?line->transTo:line->transFrom;
 			if (!stringPtr) continue;
-			listitem = g_convert(stringPtr, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
-			if (listitem) {
-				gtk_list_store_set(listStore, &iter, 2*k, listitem, -1);
-				g_free(listitem);
+
+			if (g_utf8_validate(stringPtr, -1, NULL)) {
+				gtk_list_store_set(listStore, &iter, 2*k, stringPtr, -1);
 			} else {
 				badChars = TRUE;
-				listitem = new char[1000];
-				listitem = strcpy(listitem, stringPtr);
-				int retval = 1;
-				replaceInvalidCharacters(listitem, &retval);
-				if (!retval) {
-					badChars = TRUE;
-				}
-				gtk_list_store_set(listStore, &iter, 2*k, listitem, -1);
-				delete listitem;
 			}
-			listitem = NULL;
 		}
 		gtk_list_store_set(listStore, &iter, COLUMN_TRANSLATE, line?line->type != TYPE_NONE:FALSE, -1);
 		gtk_list_store_set(listStore, &iter, COLUMN_ID, stringId, -1);
@@ -195,8 +174,10 @@ void SludgeTranslationEditor::listChanged()
 		line = line->next;
 	}
 
-	if (badChars)
-			errorBox("Invalid characters!", "SLUDGE scripts in the project or the translation file contain characters that are encoded in something else than ISO-8859-1. I will show an underscore in place of these characters. Use the ISO-8859-1 encoding for SLUDGE scripts and translation files. If you need support for translation files with other ISO-8859 encodings in the SLUDGE Translation Editor, contact the SLUDGE developers.");
+	if (badChars || badLangName) {
+		on_new();
+		errorBox("Invalid characters!", "The translation file or SLUDGE scripts in the project contain characters that are encoded in something else than UTF-8. Starting with SLUDGE 2.2 all SLUDGE scripts have to be UTF-8 encoded. Please convert your files.");
+	}
 }
 
 // Callbacks:
@@ -346,7 +327,6 @@ void SludgeTranslationEditor::on_column_changed(int column, GtkCellRenderer *the
 	GtkTreeIter iter;
 	gchar *indexStr;
 	int index;
-	char *latin1NewText;
 
 	sortedPath = gtk_tree_path_new_from_string(thePath);
 	filterPath = gtk_tree_model_sort_convert_path_to_child_path(GTK_TREE_MODEL_SORT(sortModel), sortedPath);
@@ -397,29 +377,20 @@ void SludgeTranslationEditor::on_column_changed(int column, GtkCellRenderer *the
 				}
 			}
 
-			latin1NewText = g_convert(theNewText, -1, "ISO-8859-1", "UTF-8", NULL, NULL, NULL);
-			
-			if (!latin1NewText) {
-				errorBox("Invalid string!", "This translation contains characters that have no representation in the ISO-8859-1 character encoding. Use this encoding for SLUDGE scripts and translation files. If you need support for translation files with other ISO-8859 encodings in the SLUDGE Translation Editor, contact the SLUDGE developers.");
-				return;
-			}
-
 			if (line->transTo) {
-				if (! strcmp(line->transTo, latin1NewText)) {
-					g_free(latin1NewText);
+				if (! strcmp(line->transTo, theNewText)) {
 					return;
 				} else {
 					setFileChanged();
 				}
 				deleteString(line->transTo);
 				line->transTo = NULL;
-			} else if (! strlen(latin1NewText)) {
-				g_free(latin1NewText);
+			} else if (! strlen(theNewText)) {
 				return;
 			} else {
 				setFileChanged();
 			}
-			line->transTo = copyString(latin1NewText);
+			line->transTo = copyString(theNewText);
 			if (!strlen(line->transTo)) {
 				if (line->type != TYPE_NONE)
 					line->type = TYPE_NEW;
@@ -430,7 +401,6 @@ void SludgeTranslationEditor::on_column_changed(int column, GtkCellRenderer *the
 			}
 			gtk_list_store_set(listStore, &iter, COLUMN_TRANSLATION, theNewText, -1);
 			on_tree_selection_changed(selection);
-			g_free(latin1NewText);
 			break;
 		}
 		default:
