@@ -13,6 +13,8 @@
 #include "allknown.h"
 #include "compilerinfo.h"
 
+#include "utf8.h"
+
 extern char * inThisClass;
 
 // Sludge commands
@@ -894,6 +896,11 @@ void doDefines (char * fn, stringArray * & strings, stringArray * & fileHandles)
 		for (;;) {
 			char * t = readText (fp);
 			if (!t) break;
+			if (! u8_isvalid(t)) {
+				addComment (ERRORTYPE_PROJECTERROR, "Invalid string found. (It is not UTF-8 encoded.)", NULL, fn, 0);
+				return;
+			}
+			
 			stringArray * sa = splitString (t, '#');
 			if (sa -> string[0]) {
 				stringArray * bits = splitString (sa -> string, '=', ONCE);
@@ -916,9 +923,13 @@ void doDefines (char * fn, stringArray * & strings, stringArray * & fileHandles)
 						delete bits->next->string;
 						bits->next->string = newTarget;
 					}
-
-					addToStringArray (typeDefFrom, bits -> string);
-					addToStringArray (typeDefTo,   bits -> next -> string);
+					
+					if (! bits->next->string[0]) {
+						addComment (ERRORTYPE_PROJECTERROR, "Constant is not given a value", bits -> string, fn, 0);
+					} else {
+						addToStringArray (typeDefFrom, bits -> string);
+						addToStringArray (typeDefTo,   bits -> next -> string);
+					}
 				} else {
 					addComment (ERRORTYPE_PROJECTERROR, "No = in definition line", sa -> string, fn, 0);
 				}
