@@ -2,7 +2,7 @@
 #include "graphics.h"
 
 #if !defined(HAVE_GLES2)
-#include "GLee.h"
+#include <GL/glew.h>
 #else
 #include <GLES2/gl2.h>
 #endif
