@@ -5,9 +5,9 @@
 //---------------------------------------
 
 #define ERROR_VERSION_TOO_LOW_1		"This SLUDGE file requires a more recent version of the SLUDGE engine"
-#define ERROR_VERSION_TOO_LOW_2		"(it was created for v%i.%i).\n\nVisit http://opensludge.sourceforge.net/ to download the most recent version."
+#define ERROR_VERSION_TOO_LOW_2		"(it was created for v%i.%i).\n\nVisit http://opensludge.github.io/ to download the most recent version."
 #define ERROR_VERSION_TOO_HIGH_1 	"This SLUDGE file was created for an older version of the SLUDGE engine"
-#define ERROR_VERSION_TOO_HIGH_2	"(v%i.%i).\n\nPlease contact the author of this game to obtain a version compatible with your SLUDGE engine (v"TEXT_VERSION")."
+#define ERROR_VERSION_TOO_HIGH_2	"(v%i.%i).\n\nPlease contact the author of this game to obtain a version compatible with your SLUDGE engine (v" TEXT_VERSION ")."
 #define ERROR_BAD_HEADER			"Bad header information... this isn't a valid SLUDGE game"
 #define ERROR_HACKER				"What have you been up to? Think we're a hacker, do we? Nice try."
 
@@ -24,15 +24,15 @@
 #define ERROR_INDEX_NONSTACK		"Tried to index a non-stack variable"
 #define ERROR_NOSTACK				"Corrupt file - no stack"
 #define ERROR_UNKNOWN_CODE			"Unimplemented internal SLUDGE command code."
-#define ERROR_OUT_OF_MEMORY			"Out of memory!"_NO_MEMORY_GENERAL_
+#define ERROR_OUT_OF_MEMORY			"Out of memory!" _NO_MEMORY_GENERAL_
 
 #define ERROR_MUSIC_MEMORY_LOW		"Your computer doesn't have enough memory available to load a music resource that needs playing." _NO_MEMORY_GENERAL_
 #define ERROR_SOUND_MEMORY_LOW		"Your computer doesn't have enough memory available to load a sound resource that needs playing." _NO_MEMORY_GENERAL_
 #define ERROR_MUSIC_UNKNOWN			"I can't understand a piece of music which I've been told to play!\n\n" \
 									"Maybe it's stored in a format that SLUDGE doesn't know about... " \
-									"make sure you've got a recent version of the SLUDGE engine from http://opensludge.sourceforge.net/. " \
+									"make sure you've got a recent version of the SLUDGE engine from http://opensludge.github.io/. " \
 									"Failing that, maybe the resource in question isn't a valid music format at all... in which case, contact the game's author and tell them what's happened."
-#define ERROR_SOUND_UNKNOWN			"I can't understand a sample which I've been told to play!\nMake sure you've got the latest SLUDGE engine from http://opensludge.sourceforge.net/. Failing that, maybe the resource in question isn't a valid sound at all... in which case, contact the game's author and tell them what's happened."
+#define ERROR_SOUND_UNKNOWN			"I can't understand a sample which I've been told to play!\nMake sure you've got the latest SLUDGE engine from http://opensludge.github.io/. Failing that, maybe the resource in question isn't a valid sound at all... in which case, contact the game's author and tell them what's happened."
 #define ERROR_MUSIC_ODDNESS			"I can't load a music resource I've been told to play. Sorry."
 #define ERROR_SOUND_ODDNESS			"I can't load a sound resource I've been told to play. Sorry."
 #define ERROR_MOVIE_ODDNESS			"I can't load a music resource I've been told to play. Sorry."
