@@ -147,18 +147,43 @@ void storeTextureDimensions(GLuint name, GLsizei width,  GLsizei height, const c
 	list->width = width;
 	list->height = height;
 }
-
+#ifdef HAVE_GLES2
+void glesCopyTexSubImage2D(GLenum target,  GLint level, GLint xoffset, GLint yoffset, GLint x,  GLint y,  GLsizei width,  GLsizei height)
+{
+	// Work around for broken glCopy(Sub)TexImage2D...
+    void* tmp = malloc(width*height*4);
+    glReadPixels(x, y, width, height, GL_RGBA, GL_UNSIGNED_BYTE, tmp);
+    glTexSubImage2D(target, level, xoffset, yoffset, width, height, GL_RGBA, GL_UNSIGNED_BYTE, tmp);
+    free(tmp);
+}
+void glesCopyTexImage2D(GLenum target,  GLint level,  GLenum internalformat,  GLint x,  GLint y,  GLsizei width,  GLsizei height,  GLint border)
+{
+	// Work around for broken glCopy(Sub)TexImage2D...
+	void* tmp = malloc(width*height*4);
+	glReadPixels(x, y, width, height, GL_RGBA, GL_UNSIGNED_BYTE, tmp);
+	glTexImage2D(target, level, GL_RGBA, width, height, border, GL_RGBA, GL_UNSIGNED_BYTE, tmp);
+	free(tmp);
+}
+#endif
 
 void dcopyTexImage2D(GLenum target,  GLint level,  GLenum internalformat,  GLint x,  GLint y,  GLsizei width,  GLsizei height,  GLint border, GLuint name, const char *file, int line)
 {
 	glBindTexture(GL_TEXTURE_2D, name);
+	#ifdef HAVE_GLES2_
+	glesCopyTexImage2D(target, level, internalformat, x, y, width, height, border);
+	#else
 	glCopyTexImage2D(target, level, internalformat, x, y, width, height, border);
+	#endif
 }
 
 void dcopyTexSubImage2D(GLenum target,  GLint level,  GLint xoffset,  GLint yoffset,  GLint x,  GLint y,  GLsizei width,  GLsizei height, GLuint name, const char *file, int line)
 {
 	glBindTexture(GL_TEXTURE_2D, name);
+	#ifdef HAVE_GLES2_
+	glesCopyTexSubImage2D(target, level, xoffset, yoffset, x, y, width, height);
+	#else
 	glCopyTexSubImage2D(target, level, xoffset, yoffset, x, y, width, height);
+	#endif
 }
 
 void dtexImage2D(GLenum target,  GLint level,  GLint internalformat,  GLsizei width,  GLsizei height, 
@@ -303,7 +328,28 @@ int desktopW = 0, desktopH = 0;
 bool runningFullscreen = false;
 
 
-#if defined _WIN32 || defined(HAVE_GLES2)
+#if defined(HAVE_GLES2)
+void saveTexture (GLuint tex, GLubyte * data) {
+	// use an FBO to easily grab the texture...
+	static GLuint fbo = 0;
+	GLuint old_fbo;
+	GLint tw, th;
+	GLint old_vp[4];
+	if (fbo==0) {
+		glGenFramebuffers(1, &fbo);
+	}
+	glGetIntegerv(GL_FRAMEBUFFER_BINDING, (GLint*)&old_fbo);
+	glBindFramebuffer(GL_FRAMEBUFFER, fbo);
+	glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, tex, 0);
+	getTextureDimensions(tex, &tw, &th);
+	glGetIntegerv(GL_VIEWPORT, old_vp);
+	glViewport(0,0, tw, th);
+	glBindFramebuffer(GL_FRAMEBUFFER, fbo);
+	glReadPixels(0, 0, tw, th, GL_RGBA, GL_UNSIGNED_BYTE, data);
+	glViewport(old_vp[0], old_vp[1], old_vp[2], old_vp[3]);
+	glBindFramebuffer(GL_FRAMEBUFFER, old_fbo);
+}
+#elif defined _WIN32
 // Replacement for glGetTexImage, because some ATI drivers are buggy.
 void saveTexture (GLuint tex, GLubyte * data) {
 	setPixelCoords (true);
@@ -369,6 +415,9 @@ void saveTexture (GLuint tex, GLubyte * data) {
 // This is for setting windowed or fullscreen graphics.
 // Used for switching, and for initial window creation.
 void setGraphicsWindow(bool fullscreen, bool restoreGraphics, bool resize) {
+#if defined(PANDORA)
+	fullscreen = true;
+#endif
 
 	GLubyte *snapTexture = NULL;
 
@@ -508,16 +557,26 @@ void setGraphicsWindow(bool fullscreen, bool restoreGraphics, bool resize) {
 
 	if( SDL_SetVideoMode( realWinWidth, realWinHeight, 32, videoflags ) == 0 ) {
 		msgBox("Startup Error: Couldn't set video mode.", SDL_GetError());
-#if defined(HAVE_GLES2)
-		EGL_Close();
-#endif
 		SDL_Quit();
 		exit(2);
 	}
 	debugOut( "Video mode %d %d set successfully.\n", realWinWidth, realWinHeight);
 
 #if defined(HAVE_GLES2)
+	if (EGL_Open()) {
+		msgBox("Startup Error", "Couldn't initialize EGL.");
+		SDL_Quit();
+		exit(1);
+	}
 	EGL_Init();
+#else
+	GLenum glewErr = glewInit();
+	if (GLEW_OK != glewErr)
+	{
+		msgBox("Startup Error: Couldn't initialize GLEW.", (const char*)glewGetErrorString(glewErr));
+		SDL_Quit();
+		exit(1);
+	}
 #endif
 
 	GLint uniform;
@@ -781,48 +840,48 @@ void setupOpenGLStuff() {
 
 #if !defined(HAVE_GLES2)
 	/* Check for graphics capabilities... */
-	if (GLEE_VERSION_2_0) {
+	if (GLEW_VERSION_2_0) {
 		// Yes! Textures can be any size!
 		NPOT_textures = true;
 		debugOut( "OpenGL 2.0! All is good.\n");
 	} else {
-		if (GLEE_VERSION_1_5) {
+		if (GLEW_VERSION_1_5) {
 			debugOut("OpenGL 1.5!\n");
 		}
-		else if (GLEE_VERSION_1_4) {
+		else if (GLEW_VERSION_1_4) {
 			debugOut("OpenGL 1.4!\n");
 		}
-		else if (GLEE_VERSION_1_3) {
+		else if (GLEW_VERSION_1_3) {
 			debugOut( "OpenGL 1.3!\n");
 		}
-		else if (GLEE_VERSION_1_2) {
+		else if (GLEW_VERSION_1_2) {
 			debugOut( "OpenGL 1.2!\n");
 		}
-		if (GLEE_ARB_texture_non_power_of_two) {
+		if (GLEW_ARB_texture_non_power_of_two) {
 			// Yes! Textures can be any size!
 			NPOT_textures = true;
 		} else {
 			// Workaround needed for lesser graphics cards. Let's hope this works...
 			NPOT_textures = false;
-			debugOut( "Warning: Old graphics card! GLEE_ARB_texture_non_power_of_two not supported.\n");
+			debugOut( "Warning: Old graphics card! GLEW_ARB_texture_non_power_of_two not supported.\n");
 		}
 
-		if (GLEE_ARB_shading_language_100) {
+		if (GLEW_ARB_shading_language_100) {
 			debugOut("ARB_shading_language_100 supported.\n");
 		} else {
 			debugOut("Warning: Old graphics card! ARB_shading_language_100 not supported. Try updating your drivers.\n");
 		}
-		if (GLEE_ARB_shader_objects) {
+		if (GLEW_ARB_shader_objects) {
 			debugOut("ARB_shader_objects supported.\n");
 		} else {
 			fatal("Error: Old graphics card! ARB_shader_objects not supported.\n");
 		}
-		if (GLEE_ARB_vertex_shader) {
+		if (GLEW_ARB_vertex_shader) {
 			debugOut("ARB_vertex_shader supported.\n");
 		} else {
 			fatal("Error: Old graphics card! ARB_vertex_shader not supported.\n");
 		}
-		if (GLEE_ARB_fragment_shader) {
+		if (GLEW_ARB_fragment_shader) {
 			debugOut("ARB_fragment_shader supported.\n");
 		} else {
 			fatal("Error: Old graphics card! ARB_fragment_shader not supported.\n");
