@@ -9,7 +9,7 @@
 
 
 #if !defined(HAVE_GLES2)
-#include "GLee.h"
+#include <GL/glew.h>
 #else
 #include <GLES2/gl2.h>
 #endif
