@@ -5,6 +5,7 @@
 #include "colours.h"
 #include "backdrop.h"
 #include "graphics.h"
+#include "newfatal.h"
 
 extern GLuint snapshotTextureName;
 extern unsigned char brightnessLevel;
@@ -22,61 +23,55 @@ unsigned char fadeMode = 2;
 unsigned lastFrom, lastTo;
 
 void transitionFader () {
-	glDisable (GL_TEXTURE_2D);
-	glColor4ub (0, 0, 0, 255 - brightnessLevel);
-	
 	glEnable(GL_BLEND);
 	
-	const GLint vertices[] = { 
-		0, winHeight, 0, 
-		winWidth, winHeight, 0, 
-		winWidth, 0, 0, 
-		0, 0, 0
+	const GLfloat vertices[] = { 
+		0.f, (GLfloat)winHeight, 0.f, 
+		(GLfloat)winWidth, (GLfloat)winHeight, 0.f, 
+		0.f, 0.f, 0.f,
+		(GLfloat)winWidth, 0.f, 0.f
 	};
 
-	glEnableClientState(GL_VERTEX_ARRAY);
-	glVertexPointer(3, GL_INT, 0, vertices);
-	glDrawArrays(GL_QUADS, 0, 4);
-	glDisableClientState(GL_VERTEX_ARRAY);
+	glUseProgram(shader.color);
+	setPMVMatrix(shader.color);
+	setPrimaryColor(0.0f, 0.0f, 0.0f, 1.0f - brightnessLevel/255.f);
+	drawQuad(shader.color, vertices, 0);
+
+	glUseProgram(0);
 
 	glDisable(GL_BLEND);
-	glEnable (GL_TEXTURE_2D);
 }
 
 void transitionCrossFader () {
 
 	if (! snapshotTextureName) return;
-	
-	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub (255, 255, 255, 255 - brightnessLevel);
+
 	glBindTexture (GL_TEXTURE_2D,snapshotTextureName);
 	
 	glEnable(GL_BLEND);
-	
-	const GLint vertices[] = { 
-		0, winHeight, 0, 
-		winWidth, winHeight, 0, 
-		winWidth, 0, 0, 
-		0, 0, 0
+
+	const GLfloat vertices[] = { 
+		0.f, (GLfloat)winHeight, 0.f, 
+		(GLfloat)winWidth, (GLfloat)winHeight, 0.f, 
+		0.f, 0.f, 0.f,
+		(GLfloat)winWidth, 0.f, 0.f
 	};
 
 	const GLfloat texCoords[] = { 
 		0.0f, snapTexH,
 		snapTexW, snapTexH,
-		snapTexW, 0.0f, 
-		0.0f, 0.0f
+		0.0f, 0.0f,
+		snapTexW, 0.0f
 	}; 
 
-	glEnableClientState(GL_VERTEX_ARRAY);
-	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+	glUseProgram(shader.texture);
+	setPMVMatrix(shader.texture);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 1);
+	setPrimaryColor(1.0f, 1.0f, 1.0f, 1.0f - brightnessLevel/255.f);
 
-	glVertexPointer(3, GL_INT, 0, vertices);
-	glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
-
-	glDrawArrays(GL_QUADS, 0, 4);
-
-	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-	glDisableClientState(GL_VERTEX_ARRAY);
+	drawQuad(shader.texture, vertices, 1, texCoords);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 0);
+	glUseProgram(0);
 
 	glDisable(GL_BLEND);
 }
@@ -85,7 +80,7 @@ void transitionSnapshotBox () {
 	
 	if (! snapshotTextureName) return; 
 
-	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	//glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
 	glBindTexture (GL_TEXTURE_2D,snapshotTextureName);
 	
 	float xScale = (float) brightnessLevel * winWidth / 510.f;	// 510 = 255*2
@@ -94,27 +89,22 @@ void transitionSnapshotBox () {
 	const GLfloat vertices[] = { 
 		xScale, winHeight-yScale, 0, 
 		winWidth-xScale, winHeight-yScale, 0, 
-		winWidth-xScale, yScale, 0, 
-		xScale, yScale, 0
+		xScale, yScale, 0,
+		winWidth-xScale, yScale, 0
 	};
 
 	const GLfloat texCoords[] = { 
 		0.0f, snapTexH,
 		snapTexW, snapTexH,
-		snapTexW, 0.0f, 
-		0.0f, 0.0f
+		0.0f, 0.0f,
+		snapTexW, 0.0f
 	}; 
 
-	glEnableClientState(GL_VERTEX_ARRAY);
-	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+	glUseProgram(shader.texture);
+	setPMVMatrix(shader.texture);
 
-	glVertexPointer(3, GL_FLOAT, 0, vertices);
-	glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
-
-	glDrawArrays(GL_QUADS, 0, 4);
-
-	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-	glDisableClientState(GL_VERTEX_ARRAY);
+	drawQuad(shader.texture, vertices, 1, texCoords);
+	glUseProgram(0);
 }
 
 //----------------------------------------------------
@@ -145,8 +135,10 @@ bool reserveTransitionTexture () {
 	
 	glPixelStorei (GL_UNPACK_ALIGNMENT, 1);
 	
-	if (! transitionTexture) 
+	if (! transitionTexture) {
 		transitionTexture = new GLubyte [256*256*4];
+		if (! checkNew (transitionTexture)) return false;
+	}
 	
 	if (! transitionTextureName) glGenTextures (1, &transitionTextureName);
 	glBindTexture (GL_TEXTURE_2D, transitionTextureName);
@@ -155,7 +147,7 @@ bool reserveTransitionTexture () {
 	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
 	
-	glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, transitionTexture);
+	texImage2D (GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, transitionTexture, transitionTextureName);
 	
 	return true;
 }
@@ -198,38 +190,32 @@ void transitionDisolve () {
 		toScreen += 4;
 	} while (toScreen < end);
 
-	glBindTexture (GL_TEXTURE_2D, transitionTextureName);
-	glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, transitionTexture);
+	texImage2D (GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, transitionTexture, transitionTextureName);
 
-	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub (255, 255, 255, 255);
-	
 	glEnable(GL_BLEND);
 
-	const GLint vertices[] = { 
-		0, winHeight, 0, 
-		winWidth, winHeight, 0, 
-		winWidth, 0, 0, 
-		0, 0, 0
+	const GLfloat vertices[] = { 
+		0.f, (GLfloat)winHeight, 0.f, 
+		(GLfloat)winWidth, (GLfloat)winHeight, 0.f, 
+		0.f, 0.f, 0.f,
+		(GLfloat)winWidth, 0.f, 0.f
 	};
 
 	const GLfloat texCoords[] = { 
 		0.0f, 1.0f,
 		1.0f, 1.0f,
-		1.0f, 0.0f, 
-		0.0f, 0.0f
+		0.0f, 0.0f,
+		1.0f, 0.0f
 	}; 
 
-	glEnableClientState(GL_VERTEX_ARRAY);
-	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+	glUseProgram(shader.texture);
+	setPMVMatrix(shader.texture);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 1);
+	setPrimaryColor(1.0f, 1.0f, 1.0f, 1.0f);
 
-	glVertexPointer(3, GL_INT, 0, vertices);
-	glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
-
-	glDrawArrays(GL_QUADS, 0, 4);
-
-	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-	glDisableClientState(GL_VERTEX_ARRAY);
+	drawQuad(shader.texture, vertices, 1, texCoords);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 0);
+	glUseProgram(0);
 
 	glDisable(GL_BLEND);
 }
@@ -266,71 +252,75 @@ void transitionTV () {
 		toScreen += 4;
 	} while (toScreen < end);
 	
-	glBindTexture (GL_TEXTURE_2D, transitionTextureName);
-	glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, transitionTexture);
-	
-	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub (255, 255, 255, 255);
+	texImage2D (GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, transitionTexture, transitionTextureName);
 	
 	glEnable(GL_BLEND);
 	
-	const GLint vertices[] = { 
-		0, winHeight, 0, 
-		winWidth, winHeight, 0, 
-		winWidth, 0, 0, 
-		0, 0, 0
+	const GLfloat vertices[] = { 
+		0.f, (GLfloat)winHeight, 0.f, 
+		(GLfloat)winWidth, (GLfloat)winHeight, 0.f, 
+		0.f, 0.f, 0.f,
+		(GLfloat)winWidth, 0.f, 0.f
 	};
 
 	const GLfloat texCoords[] = { 
 		0.0f, 1.0f,
 		1.0f, 1.0f,
-		1.0f, 0.0f, 
-		0.0f, 0.0f
+		0.0f, 0.0f,
+		1.0f, 0.0f
 	}; 
 
-	glEnableClientState(GL_VERTEX_ARRAY);
-	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+	glUseProgram(shader.texture);
+	setPMVMatrix(shader.texture);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 1);
+	setPrimaryColor(1.0f, 1.0f, 1.0f, 1.0f);
 
-	glVertexPointer(3, GL_INT, 0, vertices);
-	glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
-
-	glDrawArrays(GL_QUADS, 0, 4);
-
-	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-	glDisableClientState(GL_VERTEX_ARRAY);
+	drawQuad(shader.texture, vertices, 1, texCoords);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 0);
+	glUseProgram(0);
 
 	glDisable(GL_BLEND);	
 }
 
 void transitionBlinds () {
-	GLubyte stippleMask[128];
+	if (! transitionTextureName) reserveTransitionTexture();
+	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
+
+	GLubyte * toScreen = transitionTexture;
 
 	int level = brightnessLevel/8;
 	
-	if (level) memset (stippleMask, 0, 4*level);
-	if (level < 32) memset (stippleMask+level*4, 255, 4*(32-level));
+	if (level) memset (toScreen, 0, 256*32*level);
+	if (level < 32) memset (toScreen+256*32*level, 255, 256*32*(32-level));
+	
+	texImage2D (GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, transitionTexture, transitionTextureName);
 
-	glDisable (GL_TEXTURE_2D);
-	glColor4ub (0, 0, 0, 255);
-	
-	glPolygonStipple(stippleMask);
-	glEnable(GL_POLYGON_STIPPLE);
-	
-	const GLint vertices[] = { 
-		0, winHeight, 0, 
-		winWidth, winHeight, 0, 
-		winWidth, 0, 0, 
-		0, 0, 0
+	glEnable(GL_BLEND);
+
+	const GLfloat vertices[] = { 
+		0.f, (GLfloat)winHeight, 0.f, 
+		(GLfloat)winWidth, (GLfloat)winHeight, 0.f, 
+		0.f, 0.f, 0.f,
+		(GLfloat)winWidth, 0.f, 0.f
 	};
 
-	glEnableClientState(GL_VERTEX_ARRAY);
-	glVertexPointer(3, GL_INT, 0, vertices);
-	glDrawArrays(GL_QUADS, 0, 4);
-	glDisableClientState(GL_VERTEX_ARRAY);
+	const GLfloat texCoords[] = { 
+		0.0f, 0.0f,
+		1.0f, 0.0f,
+		0.0f, 25.0f,
+		1.0f, 25.0f
+	}; 
 
-	glDisable(GL_POLYGON_STIPPLE);
-	glEnable (GL_TEXTURE_2D);
-	
+	glUseProgram(shader.texture);
+	setPMVMatrix(shader.texture);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 1);
+	setPrimaryColor(0.0f, 0.0f, 0.0f, 1.0f);
+
+	drawQuad(shader.texture, vertices, 1, texCoords);
+	glUniform1i(glGetUniformLocation(shader.texture, "modulateColor"), 0);
+	glUseProgram(0);
+
+	glDisable(GL_BLEND);
 }
 
 //----------------------------------------------------
