@@ -12,7 +12,7 @@ extern int sceneWidth, sceneHeight;
 
 void killZBuffer () {
 	if (zBuffer.tex) {
-		glDeleteTextures (1, &zBuffer.texName);
+		deleteTextures (1, &zBuffer.texName);
 		zBuffer.texName = 0;
 		delete zBuffer.tex;
 		zBuffer.tex = NULL;
@@ -92,6 +92,7 @@ bool setZBuffer (int y) {
 		picHeight = getNextPOT(picHeight);
 	}
 	zBuffer.tex = new GLubyte [picHeight*picWidth];
+	if (! checkNew (zBuffer.tex)) return false;
 
 	for (y = 0; y < sceneHeight; y ++) {
 		for (x = 0; x < sceneWidth; x ++) {
@@ -116,7 +117,7 @@ bool setZBuffer (int y) {
 	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
 	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-	glTexImage2D (GL_TEXTURE_2D, 0, GL_ALPHA8, picWidth, picHeight, 0, GL_ALPHA, GL_UNSIGNED_BYTE, zBuffer.tex);
+	texImage2D (GL_TEXTURE_2D, 0, GL_ALPHA, picWidth, picHeight, 0, GL_ALPHA, GL_UNSIGNED_BYTE, zBuffer.tex, zBuffer.texName);
 	
 	
 	return true;
@@ -129,19 +130,19 @@ void drawZBuffer(int x, int y, bool upsidedown) {
 	
 	glEnable(GL_DEPTH_TEST);
 	glEnable(GL_BLEND);
-	glEnable(GL_ALPHA_TEST);
 	glColorMask (GL_FALSE, GL_FALSE, GL_FALSE, GL_FALSE);
 	glDepthMask (GL_TRUE);
-	
-	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+
+	glUseProgram(shader.texture);
+	setPMVMatrix(shader.texture);
+
+	//glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 	glBindTexture (GL_TEXTURE_2D, zBuffer.texName);
-	glColor4f(1.0, 1.0, 1.0, 1.0);
+	setPrimaryColor(1.0, 1.0, 1.0, 1.0);
 
 	for (i = 1; i<zBuffer.numPanels; i++) {
 		GLfloat z = 1.0 - (double) i * (1.0 / 128.0);
 
-		glAlphaFunc (GL_GREATER, 0.0625*i-0.03);
-
 		GLfloat vy1 = -y, vy2 = zBuffer.height-y;
 		if (upsidedown) {
 			vy1 += zBuffer.height;
@@ -151,32 +152,27 @@ void drawZBuffer(int x, int y, bool upsidedown) {
 		const GLfloat vertices[] = { 
 			(GLfloat)-x, vy1, z,
 			(GLfloat)zBuffer.width-x, vy1, z, 
-			(GLfloat)zBuffer.width-x, vy2, z, 
-			(GLfloat)-x, vy2, z
+			(GLfloat)-x, vy2, z,
+			(GLfloat)zBuffer.width-x, vy2, z
 		};
 
 		const GLfloat texCoords[] = { 
 			0.0f, 0.0f,
 			backdropTexW, 0.0f,
-			backdropTexW, backdropTexH, 
-			0.0f, backdropTexH
+			0.0f, backdropTexH,
+			backdropTexW, backdropTexH
 		}; 
 
-		glEnableClientState(GL_VERTEX_ARRAY);
-		glEnableClientState(GL_TEXTURE_COORD_ARRAY);
-
-		glVertexPointer(3, GL_FLOAT, 0, vertices);
-		glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
-
-		glDrawArrays(GL_QUADS, 0, 4);
-
-		glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-		glDisableClientState(GL_VERTEX_ARRAY);
+		glUniform1i(glGetUniformLocation(shader.texture, "zBuffer"), 1);
+		glUniform1f(glGetUniformLocation(shader.texture, "zBufferLayer"), i);
+ 
+		drawQuad(shader.texture, vertices, 1, texCoords);
+		glUniform1i(glGetUniformLocation(shader.texture, "zBuffer"), 0);
 	}
 	
 	glColorMask (GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
 	glDepthMask (GL_FALSE);
-	glDisable(GL_ALPHA_TEST);
 	glDisable(GL_BLEND);	
+	glUseProgram(0);
 }
 
